@@ -1,5 +1,5 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
+from ocp_resources.utils import TimeoutExpiredError, nudge_delete
 
 
 class Project(Resource):
@@ -25,23 +25,11 @@ class ProjectRequest(Resource):
 
     def __init__(
         self,
-        name=None,
+        name,
         client=None,
         teardown=True,
-        timeout=TIMEOUT_4MINUTES,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
-        super().__init__(
-            name=name,
-            client=client,
-            teardown=teardown,
-            timeout=timeout,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
-        )
+        super().__init__(name=name, client=client, teardown=teardown)
 
     def clean_up(self):
         Project(name=self.name).delete(wait=True)
@@ -54,4 +42,7 @@ class ProjectRequest(Resource):
             timeout (int): Time to wait for the resource.
 
         """
-        super().client_wait_deleted(timeout=timeout)
+        try:
+            super().client_wait_deleted(timeout=timeout)
+        except TimeoutExpiredError:
+            nudge_delete(name=self.name)
