@@ -1,45 +1,21 @@
-import contextlib
 import json
+import logging
 import os
 import re
-import sys
-from io import StringIO
-from signal import SIGINT, signal
+from distutils.version import Version
 
 import kubernetes
 import urllib3
-import yaml
 from openshift.dynamic import DynamicClient
-from openshift.dynamic.exceptions import (
-    ConflictError,
-    InternalServerError,
-    NotFoundError,
-    ServerTimeoutError,
-)
-from openshift.dynamic.resource import ResourceField
-from packaging.version import Version
+from openshift.dynamic.exceptions import InternalServerError, NotFoundError
+from urllib3.exceptions import ProtocolError
 
-from ocp_resources.constants import (
-    NOT_FOUND_ERROR_EXCEPTION_DICT,
-    PROTOCOL_ERROR_EXCEPTION_DICT,
-    TIMEOUT_4MINUTES,
-)
-from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-DEFAULT_CLUSTER_RETRY_EXCEPTIONS = {
-    ConnectionAbortedError: [],
-    ConnectionResetError: [],
-    InternalServerError: [
-        "etcdserver: leader changed",
-        "etcdserver: request timed out",
-    ],
-    ServerTimeoutError: [],
-}
-
-LOGGER = get_logger(name=__name__)
-MAX_SUPPORTED_API_VERSION = "v2"
+LOGGER = logging.getLogger(__name__)
+TIMEOUT = 240
+MAX_SUPPORTED_API_VERSION = "v1"
 
 
 def _collect_instance_data(directory, resource_object):
@@ -134,8 +110,6 @@ def _get_api_version(dyn_client, api_group, kind):
         log = f"Couldn't find {kind} in {api_group} api group"
         LOGGER.warning(log)
         raise NotImplementedError(log)
-
-    LOGGER.info(f"kind: {kind} api version: {res.group_version}")
     return res.group_version
 
 
@@ -143,12 +117,12 @@ def sub_resource_level(current_class, owner_class, parent_class):
     # return the name of the last class in MRO list that is not one of base
     # classes; otherwise return None
     for class_iterator in reversed(
-        [
+        list(
             class_iterator
             for class_iterator in current_class.mro()
             if class_iterator not in owner_class.mro()
             and issubclass(class_iterator, parent_class)
-        ]
+        )
     ):
         return class_iterator.__name__
 
@@ -164,13 +138,15 @@ class KubeAPIVersion(Version):
     def __init__(self, vstring=None):
         self.vstring = vstring
         self.version = None
-        super().__init__(version=vstring)
+        super().__init__(vstring=vstring)
 
     def parse(self, vstring):
-        components = [comp for comp in self.component_re.split(vstring) if comp]
-        for idx, obj in enumerate(components):
-            with contextlib.suppress(ValueError):
-                components[idx] = int(obj)
+        components = [x for x in self.component_re.split(vstring) if x]
+        for i, obj in enumerate(components):
+            try:
+                components[i] = int(obj)
+            except ValueError:
+                pass
 
         errmsg = f"version '{vstring}' does not conform to kubernetes api versioning guidelines"
 
@@ -212,7 +188,7 @@ class KubeAPIVersion(Version):
             return 1
 
 
-class ClassProperty:
+class classproperty(object):  # noqa: N801
     def __init__(self, func):
         self.func = func
 
@@ -225,8 +201,10 @@ class ValueMismatch(Exception):
     Raises when value doesn't match the class value
     """
 
+    pass
 
-class Resource:
+
+class Resource(object):
     """
     Base class for API resources
     """
@@ -242,8 +220,6 @@ class Resource:
         DEPLOYED = "Deployed"
         PENDING = "Pending"
         COMPLETED = "Completed"
-        RUNNING = "Running"
-        TERMINATING = "Terminating"
 
     class Condition:
         UPGRADEABLE = "Upgradeable"
@@ -277,19 +253,13 @@ class Resource:
         ADMISSIONREGISTRATION_K8S_IO = "admissionregistration.k8s.io"
         APIEXTENSIONS_K8S_IO = "apiextensions.k8s.io"
         APIREGISTRATION_K8S_IO = "apiregistration.k8s.io"
-        APP_KUBERNETES_IO = "app.kubernetes.io"
         APPS = "apps"
-        BATCH = "batch"
         CDI_KUBEVIRT_IO = "cdi.kubevirt.io"
         CONFIG_OPENSHIFT_IO = "config.openshift.io"
         CONSOLE_OPENSHIFT_IO = "console.openshift.io"
-        EVENTS_K8S_IO = "events.k8s.io"
-        FLAVOR_KUBEVIRT_IO = "flavor.kubevirt.io"
-        FORKLIFT_KONVEYOR_IO = "forklift.konveyor.io"
         HCO_KUBEVIRT_IO = "hco.kubevirt.io"
         HOSTPATHPROVISIONER_KUBEVIRT_IO = "hostpathprovisioner.kubevirt.io"
         IMAGE_OPENSHIFT_IO = "image.openshift.io"
-        IMAGE_REGISTRY = "registry.redhat.io"
         K8S_CNI_CNCF_IO = "k8s.cni.cncf.io"
         K8S_V1_CNI_CNCF_IO = "k8s.v1.cni.cncf.io"
         KUBERNETES_IO = "kubernetes.io"
@@ -298,29 +268,21 @@ class Resource:
         LITMUS_IO = "litmuschaos.io"
         MACHINE_OPENSHIFT_IO = "machine.openshift.io"
         MACHINECONFIGURATION_OPENSHIFT_IO = "machineconfiguration.openshift.io"
-        MAISTRA_IO = "maistra.io"
         MONITORING_COREOS_COM = "monitoring.coreos.com"
         NETWORKADDONSOPERATOR_NETWORK_KUBEVIRT_IO = (
             "networkaddonsoperator.network.kubevirt.io"
         )
-        NETWORKING_ISTIO_IO = "networking.istio.io"
         NETWORKING_K8S_IO = "networking.k8s.io"
-        NODE_LABELLER_KUBEVIRT_IO = "node-labeller.kubevirt.io"
         NMSTATE_IO = "nmstate.io"
         NODEMAINTENANCE_KUBEVIRT_IO = "nodemaintenance.kubevirt.io"
         OPERATOR_OPENSHIFT_IO = "operator.openshift.io"
         OPERATORS_COREOS_COM = "operators.coreos.com"
-        OPERATORS_OPENSHIFT_IO = "operators.openshift.io"
         OS_TEMPLATE_KUBEVIRT_IO = "os.template.kubevirt.io"
         PACKAGES_OPERATORS_COREOS_COM = "packages.operators.coreos.com"
-        POLICY = "policy"
-        POOL_KUBEVIRT_IO = "pool.kubevirt.io"
         PROJECT_OPENSHIFT_IO = "project.openshift.io"
         RBAC_AUTHORIZATION_K8S_IO = "rbac.authorization.k8s.io"
-        RIPSAW_CLOUDBULLDOZER_IO = "ripsaw.cloudbulldozer.io"
         ROUTE_OPENSHIFT_IO = "route.openshift.io"
         SCHEDULING_K8S_IO = "scheduling.k8s.io"
-        SECURITY_ISTIO_IO = "security.istio.io"
         SECURITY_OPENSHIFT_IO = "security.openshift.io"
         SNAPSHOT_STORAGE_K8S_IO = "snapshot.storage.k8s.io"
         SNAPSHOT_KUBEVIRT_IO = "snapshot.kubevirt.io"
@@ -332,27 +294,14 @@ class Resource:
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
         UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
         V2V_KUBEVIRT_IO = "v2v.kubevirt.io"
-        VM_KUBEVIRT_IO = "vm.kubevirt.io"
-        MIGRATIONS_KUBEVIRT_IO = "migrations.kubevirt.io"
 
     class ApiVersion:
         V1 = "v1"
         V1BETA1 = "v1beta1"
         V1ALPHA1 = "v1alpha1"
-        V1ALPHA3 = "v1alpha3"
 
     def __init__(
-        self,
-        name=None,
-        client=None,
-        teardown=True,
-        timeout=TIMEOUT_4MINUTES,
-        privileged_client=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        dry_run=None,
-        node_selector=None,
-        node_selector_labels=None,
+        self, name, client=None, teardown=True, timeout=TIMEOUT, privileged_client=None
     ):
         """
         Create a API resource
@@ -368,11 +317,6 @@ class Resource:
         self.name = name
         self.client = client
         self.privileged_client = privileged_client
-        self.yaml_file = yaml_file
-        self.resource_dict = None  # Filled in case yaml_file is not None
-        if not (self.name or self.yaml_file):
-            raise ValueError("name or yaml file is required")
-
         if not self.client:
             try:
                 self.client = DynamicClient(
@@ -393,41 +337,12 @@ class Resource:
 
         self.teardown = teardown
         self.timeout = timeout
-        self.delete_timeout = delete_timeout
-        self.dry_run = dry_run
-        self.node_selector = node_selector
-        self.node_selector_labels = node_selector_labels
-        self.node_selector_spec = self._prepare_node_selector_spec()
 
-    def _prepare_node_selector_spec(self):
-        if self.node_selector:
-            return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
-        if self.node_selector_labels:
-            return self.node_selector_labels
-
-    @ClassProperty
+    @classproperty
     def kind(cls):  # noqa: N805
         return sub_resource_level(cls, NamespacedResource, Resource)
 
     def _base_body(self):
-        """
-        Generate resource dict from yaml if self.yaml_file else return base resource dict.
-
-        Returns:
-            dict: Resource dict.
-        """
-        if self.yaml_file:
-            if isinstance(self.yaml_file, StringIO):
-                data = self.yaml_file.read()
-            else:
-                with open(self.yaml_file, "r") as stream:
-                    data = stream.read()
-
-            self.resource_dict = yaml.safe_load(stream=data)
-            self.resource_dict.get("metadata", {}).pop("resourceVersion", None)
-            self.name = self.resource_dict["metadata"]["name"]
-            return self.resource_dict
-
         return {
             "apiVersion": self.api_version,
             "kind": self.kind,
@@ -441,29 +356,14 @@ class Resource:
         return self._base_body()
 
     def __enter__(self):
-        signal(SIGINT, self._sigint_handler)
         return self.deploy()
 
     def __exit__(self, exception_type, exception_value, traceback):
-        # For debug, export kind (class name) + NOTEARDOWN to skip resource teardown.
-        # For example:export VirtualMachineInstanceNOTEARDOWN=True
-        skip_teardown_env = f"{self.kind}NOTEARDOWN"
-        no_teardown_from_environment = os.environ.get(skip_teardown_env)
-        if no_teardown_from_environment:
-            LOGGER.warning(
-                f"Skip teardown. Got {skip_teardown_env}={no_teardown_from_environment}"
-            )
-            return
-
         if self.teardown:
             self.clean_up()
 
-    def _sigint_handler(self, signal_received, frame):
-        self.__exit__(exception_type=None, exception_value=None, traceback=None)
-        sys.exit(signal_received)
-
-    def deploy(self, wait=False):
-        self.create(wait=wait)
+    def deploy(self):
+        self.create()
         return self
 
     def clean_up(self):
@@ -471,11 +371,11 @@ class Resource:
             try:
                 _collect_data(resource_object=self)
             except Exception as exception_:
-                LOGGER.warning(
-                    f"Log collector failed to collect info for {self.kind} {self.name}\nexception: {exception_}"
-                )
+                LOGGER.warning(exception_)
 
-        self.delete(wait=True, timeout=self.delete_timeout)
+        data = self.to_dict()
+        LOGGER.info(f"Deleting {data}")
+        self.delete(wait=True, timeout=self.timeout)
 
     @classmethod
     def _prepare_resources(cls, dyn_client, singular_name, *args, **kwargs):
@@ -489,14 +389,7 @@ class Resource:
             kind=cls.kind, api_version=cls.api_version, **get_kwargs
         ).get(*args, **kwargs)
 
-    def _prepare_singular_name_kwargs(self, **kwargs):
-        kwargs = kwargs if kwargs else {}
-        if self.singular_name:
-            kwargs["singular_name"] = self.singular_name
-
-        return kwargs
-
-    def full_api(self, **kwargs):
+    def api(self, **kwargs):
         """
         Get resource API
 
@@ -515,17 +408,13 @@ class Resource:
         Returns:
             Resource: Resource object.
         """
-        kwargs = self._prepare_singular_name_kwargs(**kwargs)
-
+        if self.singular_name:
+            kwargs["singular_name"] = self.singular_name
         return self.client.resources.get(
             api_version=self.api_version, kind=self.kind, **kwargs
         )
 
-    @property
-    def api(self):
-        return self.full_api()
-
-    def wait(self, timeout=TIMEOUT_4MINUTES, sleep=1):
+    def wait(self, timeout=TIMEOUT, sleep=1):
         """
         Wait for resource
 
@@ -540,17 +429,14 @@ class Resource:
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
-            exceptions_dict={
-                **PROTOCOL_ERROR_EXCEPTION_DICT,
-                **NOT_FOUND_ERROR_EXCEPTION_DICT,
-            },
+            exceptions=(ProtocolError, NotFoundError),
             func=lambda: self.exists,
         )
         for sample in samples:
             if sample:
                 return
 
-    def wait_deleted(self, timeout=TIMEOUT_4MINUTES):
+    def wait_deleted(self, timeout=TIMEOUT):
         """
         Wait until resource is deleted
 
@@ -590,9 +476,7 @@ class Resource:
             if not sample:
                 return
 
-    def wait_for_status(
-        self, status, timeout=TIMEOUT_4MINUTES, stop_status=None, sleep=1
-    ):
+    def wait_for_status(self, status, timeout=TIMEOUT, stop_status=None, sleep=1):
         """
         Wait for resource to be in status
 
@@ -609,8 +493,8 @@ class Resource:
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -654,34 +538,29 @@ class Resource:
             name = body.get("name")
             api_version = body["apiVersion"]
             if kind != self.kind:
-                raise ValueMismatch(f"{kind} != {self.kind}")
+                ValueMismatch(f"{kind} != {self.kind}")
             if name and name != self.name:
-                raise ValueMismatch(f"{name} != {self.name}")
+                ValueMismatch(f"{name} != {self.name}")
             if api_version != self.api_version:
-                raise ValueMismatch(f"{api_version} != {self.api_version}")
+                ValueMismatch(f"{api_version} != {self.api_version}")
 
             data.update(body)
 
-        LOGGER.info(f"Create {self.kind} {self.name}")
         LOGGER.info(f"Posting {data}")
-        LOGGER.debug(f"\n{yaml.dump(data)}")
-        res = self.api.create(body=data, namespace=self.namespace, dry_run=self.dry_run)
+        LOGGER.info(f"Create {self.kind} {self.name}")
+        res = self.api().create(body=data, namespace=self.namespace)
         if wait and res:
             return self.wait()
         return res
 
-    def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
-        LOGGER.info(f"Delete {self.kind} {self.name}")
-        if self.exists:
-            data = self.instance.to_dict()
-            LOGGER.info(f"Deleting {data}")
-            LOGGER.debug(f"\n{yaml.dump(data)}")
-
+    def delete(self, wait=False, timeout=TIMEOUT):
+        resource_list = self.api()
         try:
-            res = self.api.delete(name=self.name, namespace=self.namespace, body=body)
+            res = resource_list.delete(name=self.name, namespace=self.namespace)
         except NotFoundError:
             return False
 
+        LOGGER.info(f"Delete {self.kind} {self.name}")
         if wait and res:
             return self.wait_deleted(timeout=timeout)
         return res
@@ -706,9 +585,8 @@ class Resource:
         Args:
             resource_dict: Resource dictionary
         """
-        LOGGER.info(f"Update {self.kind} {self.name}:\n{resource_dict}")
-        LOGGER.debug(f"\n{yaml.dump(resource_dict)}")
-        self.api.patch(
+        LOGGER.info(f"Update {self.kind} {self.name}: {resource_dict}")
+        self.api().patch(
             body=resource_dict,
             namespace=self.namespace,
             content_type="application/merge-patch+json",
@@ -719,22 +597,18 @@ class Resource:
         Replace resource metadata.
         Use this to remove existing field. (update() will only update existing fields)
         """
-        LOGGER.info(f"Replace {self.kind} {self.name}: \n{resource_dict}")
-        LOGGER.debug(f"\n{yaml.dump(resource_dict)}")
-        self.api.replace(body=resource_dict, name=self.name, namespace=self.namespace)
+        LOGGER.info(f"Replace {self.kind} {self.name}: {resource_dict}")
+        self.api().replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
-    def retry_cluster_exceptions(
-        func, exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs
-    ):
-
+    def _retry_etcd_changed(func):
         sampler = TimeoutSampler(
             wait_timeout=10,
             sleep=1,
             func=func,
+            exceptions=InternalServerError,
+            exceptions_msg="etcdserver: leader changed",
             print_log=False,
-            exceptions_dict=exceptions_dict,
-            **kwargs,
         )
         for sample in sampler:
             return sample
@@ -762,7 +636,7 @@ class Resource:
             except TypeError:
                 yield cls(client=dyn_client, name=_resources.metadata.name)
 
-        return Resource.retry_cluster_exceptions(func=_get)
+        return Resource._retry_etcd_changed(func=_get)
 
     @property
     def instance(self):
@@ -774,17 +648,17 @@ class Resource:
         """
 
         def _instance():
-            return self.api.get(name=self.name)
+            return self.api().get(name=self.name)
 
-        return self.retry_cluster_exceptions(func=_instance)
+        return self._retry_etcd_changed(func=_instance)
 
     @property
     def labels(self):
         """
-        Method to get labels for this resource
+        Method to get dict of labels for this resource
 
         Returns:
-           openshift.dynamic.resource.ResourceField: Representation of labels
+           labels(dict): dict labels
         """
         return self.instance["metadata"]["labels"]
 
@@ -806,8 +680,8 @@ class Resource:
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -865,15 +739,12 @@ class NamespacedResource(Resource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         client=None,
         teardown=True,
-        timeout=TIMEOUT_4MINUTES,
+        timeout=TIMEOUT,
         privileged_client=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -881,13 +752,8 @@ class NamespacedResource(Resource):
             teardown=teardown,
             timeout=timeout,
             privileged_client=privileged_client,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
         )
         self.namespace = namespace
-        if not (self.name and self.namespace) and not self.yaml_file:
-            raise ValueError("name and namespace or yaml file is required")
 
     @classmethod
     def get(cls, dyn_client, singular_name=None, raw=False, *args, **kwargs):
@@ -934,28 +800,20 @@ class NamespacedResource(Resource):
         Returns:
             openshift.dynamic.client.ResourceInstance
         """
-        return self.api.get(name=self.name, namespace=self.namespace)
+        return self.api().get(name=self.name, namespace=self.namespace)
 
     def _base_body(self):
-        res = super(NamespacedResource, self)._base_body()
-        if self.yaml_file:
-            self.namespace = self.resource_dict["metadata"].get(
-                "namespace", self.namespace
-            )
-
-        if not self.namespace:
-            raise ValueError("Namespace must be passed or specified in the YAML file.")
-
-        if not self.yaml_file:
-            res["metadata"]["namespace"] = self.namespace
-
-        return res
+        return {
+            "apiVersion": self.api_version,
+            "kind": self.kind,
+            "metadata": {"name": self.name, "namespace": self.namespace},
+        }
 
     def to_dict(self):
         return self._base_body()
 
 
-class ResourceEditor:
+class ResourceEditor(object):
     def __init__(self, patches, action="update", user_backups=None):
         """
         Args:
@@ -980,7 +838,7 @@ class ResourceEditor:
          using an unprivileged_user; use default_client or similar instead.***
         """
 
-        self._patches = self._dictify_resourcefield(res=patches)
+        self._patches = patches
         self.action = action
         self.user_backups = user_backups
         self._backups = {}
@@ -999,9 +857,10 @@ class ResourceEditor:
     def update(self, backup_resources=False):
         """Prepares backup dicts (where necessary) and applies patches"""
         # prepare update dicts and backups
+        LOGGER.info("ResourceEdit: Backing up old data")
+
         resource_to_patch = []
         if backup_resources:
-            LOGGER.info("ResourceEdit: Backing up old data")
             if self.user_backups:
                 resource_to_patch = self._patches
                 self._backups = self.user_backups
@@ -1050,12 +909,12 @@ class ResourceEditor:
         }
 
         # apply changes
-        self._apply_patches_sampler(
+        self._apply_patches(
             patches=patches_to_apply, action_text="Updating", action=self.action
         )
 
     def restore(self):
-        self._apply_patches_sampler(
+        self._apply_patches(
             patches=self._backups, action_text="Restoring", action=self.action
         )
 
@@ -1067,23 +926,6 @@ class ResourceEditor:
         # restore backups
         self.restore()
 
-    @staticmethod
-    def _dictify_resourcefield(res):
-        """Recursively turns any ResourceField objects into dicts to avoid issues caused by appending lists, etc."""
-        if isinstance(res, ResourceField):
-            return ResourceEditor._dictify_resourcefield(res=dict(res.items()))
-        elif isinstance(res, dict):
-            return {
-                ResourceEditor._dictify_resourcefield(
-                    res=key
-                ): ResourceEditor._dictify_resourcefield(res=value)
-                for key, value in res.items()
-            }
-        elif isinstance(res, list):
-            return [ResourceEditor._dictify_resourcefield(res=x) for x in res]
-
-        return res
-
     @staticmethod
     def _create_backup(original, patch):
         """
@@ -1138,7 +980,6 @@ class ResourceEditor:
                 "ResourceEdit <action_text> for resource <resource name>"
                 will be printed for each resource; see below
         """
-
         for resource, patch in patches.items():
             LOGGER.info(
                 f"ResourceEdits: {action_text} data for "
@@ -1172,14 +1013,3 @@ class ResourceEditor:
                 resource.update_replace(
                     resource_dict=patch
                 )  # replace the resource metadata
-
-    def _apply_patches_sampler(self, patches, action_text, action):
-        exceptions_dict = {ConflictError: []}
-        exceptions_dict.update(DEFAULT_CLUSTER_RETRY_EXCEPTIONS)
-        return Resource.retry_cluster_exceptions(
-            func=self._apply_patches,
-            exceptions_dict=exceptions_dict,
-            patches=patches,
-            action_text=action_text,
-            action=action,
-        )
